@@ -5,19 +5,30 @@
 # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
 #
 # Website - http://www.pilas-engine.com.ar
-
 import os
 import interpolaciones
 import pilas
 from PySFML import sf
 import sys
+import subprocess
+import math
+
+
+PATH = os.path.dirname(os.path.abspath(__file__))
+
+
+def cargar_autocompletado():
+    "Carga los modulos de python para autocompletar desde la consola interactiva."
+    import rlcompleter
+    import readline
+
+    readline.parse_and_bind("tab: complete")
 
 def hacer_flotante_la_ventana():
     "Hace flotante la ventana para i3 (el manejador de ventanas que utiliza hugo...)"
-
     try:
-        os.system("i3-msg t >/dev/null")
-    except:
+        subprocess.call(['i3-msg', 't'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    except OSError:
         pass
 
 def centrar_la_ventana(app):
@@ -33,7 +44,7 @@ def centrar_la_ventana(app):
     to_x = desktop_mode.Width/2 - w/2
     to_y = desktop_mode.Height/2 - h/2
 
-    app.SetPosition(300, 100)
+    app.SetPosition(to_x, to_y)
 
 def es_interpolacion(an_object):
     "Indica si un objeto se comporta como una colisión."
@@ -49,7 +60,7 @@ def obtener_ruta_al_recurso(ruta):
     función intentará dar con el archivo en cuestión.
     """
 
-    dirs = ['./', os.path.dirname(sys.argv[0]), 'data', pilas.path, pilas.path + '/data']
+    dirs = ['./', os.path.dirname(sys.argv[0]), 'data', PATH, PATH + '/data']
 
     for x in dirs:
         full_path = os.path.join(x, ruta)
@@ -70,3 +81,10 @@ def esta_en_sesion_interactiva():
     except AttributeError:
         return False
 
+def distancia(a, b):
+    "Retorna la distancia entre dos numeros."
+    return abs(b - a)
+
+def distancia_entre_dos_puntos((x1, y1), (x2, y2)):
+    "Retorna la distancia entre dos puntos en dos dimensiones."
+    return math.sqrt(distancia(x1, x2) ** 2 + distancia(y1, y2))
